@@ -473,7 +473,7 @@ sub extract_git_info {
         if ($registered_url =~ /github\.com/) {
             my ($user, $repo) = $registered_url =~ m{
                 github\.com
-                [:/]([^/]+)
+                (?:(?::[0-9]+)?/|:)([^/]+)
                 /
                 ([^/]+?)(?:\.git)?
                 $
@@ -491,18 +491,20 @@ sub extract_git_info {
             };
             $homepage = $self->config->{homepage} || $http_url;
         } else {
-            # We can't do much more than this, but we need to fix
-            # user@host:path/to/repo.git to git://$host/path/to/repo.git in
-            # order to work with CPAN::Meta
-            $registered_url =~ s{
-                \A
-                [^@]+       # user name, which we toss away
-                @
-                ([^:]+)     # anything other than a ":"
-                :
-                (.+)        # anything, which is the repository
-                \Z
-            }{git://$1/$2}gx;
+            if ($registered_url !~ m{^(?:https?|ssh|git)://}) {
+                # We can't do much more than this, but we need to fix
+                # user@host:path/to/repo.git to git://$host/path/to/repo.git in
+                # order to work with CPAN::Meta
+                $registered_url =~ s{
+                    \A
+                    [^@]+       # user name, which we toss away
+                    @
+                    ([^:]+)     # anything other than a ":"
+                    :
+                    (.+)        # anything, which is the repository
+                    \Z
+                }{git://$1/$2}gx;
+            }
 
             # normal repository
             if ($registered_url !~ m{^file://}) {
